@@ -64,7 +64,7 @@ gamlssNews <- function() file.show(system.file("doc", "NEWS.txt", package="gamls
 				           "pc",                          # principal component regr : pc
 				           "h2o",                         # h2o project 
 				           "pa",                          # partial regression
-				           "gnet")                        # glmnet
+				           "gnet", "lrs")                 # glmnet and lars
                    
 # note that predict only read 2 characters Monday, May 4, 2009 at 11:27
 ##----------------------------------------------------------------------------------------
